import logging
from configparser import ConfigParser

from typing import List, Tuple

from ec2init.plans.plan_utils import HopsPlanUtils
from ec2init.plans.multinode.create_service_api_key import CreateServiceApiKey
from ec2init import Procedure

logger = logging.getLogger(__name__)

class GenerateAirflowApiKey(CreateServiceApiKey):

    @staticmethod
    def should_run(plan_utils: HopsPlanUtils) -> bool:
        check_file = plan_utils.get_procedure_check_file(GenerateAirflowApiKey.__name__)
        return not plan_utils.check_file_exists(check_file)
    
    def __init__(self, name: str, config: ConfigParser, plan_utils: HopsPlanUtils, cloud_provider: str) -> None:
        super().__init__(name, config, plan_utils, cloud_provider)
    
    def execute(self) -> List[Procedure]:
        logger.info(f"{self.name} - Generating Airflow API key")
        super().execute()
        api_key = self._get_api_key("airflow", ["PROJECT", "JOB"])

        with open("/srv/hops/airflow/secrets/api_key", 'w') as fd:
            fd.write(api_key)
        
        logger.info(f"{self.name} - Generated Airflow API key")
        self._done()

        return []
    
    def get_user_credentials(self) -> Tuple[str, str]:
        username = self.config.get('initplan', 'airflow_user_email', fallback="airflow@hopsworks.ai")
        password = self.config.get('initplan', 'airflow_user_password')
        return (username, password)

    def _done(self) -> None:
        check_file = self.plan_utils.get_procedure_check_file(GenerateAirflowApiKey.__name__)
        check_file.touch()