import logging
from pathlib import Path
from ec2init.utils.cloud import get_cloud_provider
from ec2init.utils.glassfish_asadmin import AsadminUtils
from ec2init.utils.database import databaseUtils

from configparser import ConfigParser

from typing import Any
from typing import Dict
from typing import List

from ec2init import Procedure

logger = logging.getLogger(__name__)

class ConfigureConfigNode(Procedure):
    def __init__(self, name: str, config: ConfigParser, check_file: Path, has_configured_config_node: bool, cloud_provider: str, primary_node_ip: str) -> None:
        self.name = name
        self.config = config
        self.cloud_provider = cloud_provider
        self.primary_node_ip = primary_node_ip
        self.check_file = check_file
        self.has_configured_config_node = has_configured_config_node

    def pre(self) -> None:
        if self.report_callback is not None:
            try:
                self.report_callback.execute()
            except Exception as ex:
                logger.warning("%s - Could not execute pre-execute: %s", self.name, ex)

    def execute(self) -> List[Procedure]:
        if not self.has_configured_config_node:
            private_ip = get_cloud_provider(self.cloud_provider).get_private_ip(self.config)
            data_dir = Path(self.config.get('initplan', 'hops_data_dir', fallback='/srv/hops/hopsdata'))

            kagent_conf_dir = self.config.get('general', 'kagent_conf_dir', fallback="/srv/hops/kagent/etc")
            services_file = Path(kagent_conf_dir, "services")

            try:
                AsadminUtils.configure_config_node(self.primary_node_ip, private_ip, data_dir, services_file)
            except Exception as e:
                self.friendly_name = str(e)
                raise Exception(self.friendly_name)
            
        if self.check_file:
            self.check_file.touch()

        return []

    def rollback(self) -> None:
        pass